@@ -1,5 +1,5 @@
 # This file is part of beets.
-# Copyright 2013, Adrian Sampson.
+# Copyright 2016, Adrian Sampson.
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -15,10 +15,12 @@
 """A simple utility for constructing filesystem-like trees from beets
 libraries.
 """
+
 from collections import namedtuple
+
 from beets import util
 
-Node = namedtuple('Node', ['files', 'dirs'])
+Node = namedtuple("Node", ["files", "dirs"])
 
 
 def _insert(node, path, itemid):
