@@ -30,7 +30,7 @@ def bpm(max_strokes):
     for i in range(max_strokes):
         # Press enter to the rhythm...
         s = input()
-        if s == '':
+        if s == "":
             t1 = time.time()
             # Only start measuring at the second stroke
             if t0:
@@ -46,18 +46,20 @@ def bpm(max_strokes):
 
 
 class BPMPlugin(BeetsPlugin):
-
     def __init__(self):
         super().__init__()
-        self.config.add({
-            'max_strokes': 3,
-            'overwrite': True,
-        })
+        self.config.add(
+            {
+                "max_strokes": 3,
+                "overwrite": True,
+            }
+        )
 
     def commands(self):
-        cmd = ui.Subcommand('bpm',
-                            help='determine bpm of a song by pressing '
-                            'a key to the rhythm')
+        cmd = ui.Subcommand(
+            "bpm",
+            help="determine bpm of a song by pressing " "a key to the rhythm",
+        )
         cmd.func = self.command
         return [cmd]
 
@@ -67,21 +69,23 @@ class BPMPlugin(BeetsPlugin):
         self.get_bpm(items, write)
 
     def get_bpm(self, items, write=False):
-        overwrite = self.config['overwrite'].get(bool)
+        overwrite = self.config["overwrite"].get(bool)
         if len(items) > 1:
-            raise ValueError('Can only get bpm of one song at time')
+            raise ValueError("Can only get bpm of one song at time")
 
         item = items[0]
-        if item['bpm']:
-            self._log.info('Found bpm {0}', item['bpm'])
+        if item["bpm"]:
+            self._log.info("Found bpm {0}", item["bpm"])
             if not overwrite:
                 return
 
-        self._log.info('Press Enter {0} times to the rhythm or Ctrl-D '
-                       'to exit', self.config['max_strokes'].get(int))
-        new_bpm = bpm(self.config['max_strokes'].get(int))
-        item['bpm'] = int(new_bpm)
+        self._log.info(
+            "Press Enter {0} times to the rhythm or Ctrl-D " "to exit",
+            self.config["max_strokes"].get(int),
+        )
+        new_bpm = bpm(self.config["max_strokes"].get(int))
+        item["bpm"] = int(new_bpm)
         if write:
             item.try_write()
         item.store()
-        self._log.info('Added new bpm {0}', item['bpm'])
+        self._log.info("Added new bpm {0}", item["bpm"])
